---
product: material-ui
title: React Grid（栅格）组件
components: Grid
githubLabel: 'component: Grid'
materialDesign: https://material.io/design/layout/understanding-layout.html
---

# Grid 栅格

<p class="description">Material Design 响应式布局的栅格可适应屏幕大小和方向，确保布局在不同尺寸之间的一致性。</p>

[Grid 栅格组件](https://material.io/design/layout/responsive-layout-grid.html) 能确保不同布局间的视觉层面的舒适感，同时在众多不同设计中保持灵活性。 Material Design 基于 12 列的网格布局来做到 UI 的响应式。

{{"component": "modules/components/ComponentLinkHeader.js"}}

警告，不应将`Grid`与data grid相互混淆，那是一个和布局网格相同的网格 For a data grid head to [the `DataGrid` component](/x/react-data-grid/).
:::

## 工作原理

网格系统是对`Grid`的实现

- 它使用 [CSS 弹性盒子模块](https://www.w3.org/TR/css-flexbox-1/) 来做到高度灵活。
- 它有两种类型的布局： _containers_ ， _items_。
- 每项的宽度是按百分比设置的，所以它们的大小总是相对于它们的父元素流动。
- 子项目（items）使用内边距来保持和其他块（items）的间距。
- 其中五个断点可供使用：xs，sm，md，lg 和 xl。
- 给每个断点赋予的整型值都代表了当视图宽度可以满足断点约束时组件里占用了12个可用列里的几个

如果你不熟悉flexbox，我们建议你参考 [CSS-Tricks flexbox](https://css-tricks.com/snippets/css/a-guide-to-flexbox/)篇

## Fluid grids 流式网格

流式网格可以通过列（column）来缩放和调整内容的大小。 流式网格可以用断点来决定布局是否需要大幅度变化

### 基本栅格

列宽是一个基于1-12的整型值，他们可以用于任意断点来代表组件占用了多少列

给定断点适用于其它比它更大的断点（除非重写，你会将在本页的后面看到） 举个例子，`xs={12}`会在无论他自己大小有多大的情况下将组件的宽度调整为占据整个视图宽度

{{"demo": "BasicGrid.js", "bg": true}}

### 有断点的栅格

组件可能有多个宽度定义，这会导致组件根据指定的断点大小来布局 大的断点的宽度值会覆盖小的断点的宽度值

举个例子，`xs={12} sm={6}`会在视图宽度为 [的时候让组件占据视图一半的宽度（6列）](/material-ui/customization/breakpoints/#default-breakpoints) 对于较小的视图宽度，则会占据所有的12列

{{"demo": "FullWidthGrid.js", "bg": true}}

## Spacing 间距

控制子控件之间的间距，可以使用`spacing`属性 Spacing可以是包含小数和整型值还有字符串的任意大于0的数 属性值会使用[`theme.spacing()`](/material-ui/customization/spacing/)助手来转换成css属性

{{"demo": "SpacingGrid.js", "bg": true}}

### 行、列间距

`rowSpacing`和`columnSpacing`属性允许你独立指定列间距和行间距 他和[CSS Grid](/system/grid/#row-gap-amp-column-gap)里的`row-gap`还有 `column-gap`属性相同

{{"demo": "RowAndColumnSpacing.js", "bg": true}}

## 响应式的值

You can switch the props' value based on the active breakpoint. For instance, we can implement the ["recommended"](https://material.io/design/layout/responsive-layout-grid.html) responsive layout grid of Material Design.

{{"demo": "ResponsiveGrid.js", "bg": true}}

Responsive values is supported by:

- `columns`
- `columnSpacing`
- `direction`
- `rowSpacing`
- `spacing`
- 系统中的所有[其它属性](#system-props)

:::warning
⚠️ When using a responsive `columns` prop, each grid item needs its corresponding breakpoint. For instance, this is not working. The grid item misses the value for `md`:

```jsx
<Grid container columns={{ xs: 4, md: 12 }}>
  <Grid item xs={2} />
</Grid>
```

:::

## 交互式

Below is an interactive demo that lets you explore the visual results of the different settings:

{{"demo": "InteractiveGrid.js", "hideToolbar": true, "bg": true}}

## 自适应布局

The Auto-layout makes the _items_ equitably share the available space. That also means you can set the width of one _item_ and the others will automatically resize around it.

{{"demo": "AutoGrid.js", "bg": true}}

### 负边距

Set one of the size breakpoint props to `"auto"` instead of `true` / a `number` to size a column based on the natural width of its content.

{{"demo": "VariableWidthGrid.js", "bg": true}}

## 复杂的栅格

The following demo doesn't follow the Material Design guidelines, but illustrates how the grid can be used to build complex layouts.

{{"demo": "ComplexGrid.js", "bg": true}}

## 嵌套栅格

The `container` and `item` props are two independent booleans; they can be combined to allow a Grid component to be both a flex container and child.

:::info
A flex **container** is the box generated by an element with a computed display of `flex` or `inline-flex`. In-flow children of a flex container are called flex **items** and are laid out using the flex layout model.
:::

https://www.w3.org/TR/css-flexbox-1/#box-model

{{"demo": "NestedGrid.js", "bg": true}}

⚠️ Defining an explicit width to a Grid element that is flex container, flex item, and has spacing at the same time lead to unexpected behavior, avoid doing it:

```jsx
<Grid spacing={1} container item xs={12}>
```

If you need to do such, remove one of the props.

## 列

You can change the default number of columns (12) with the `columns` prop.

{{"demo": "ColumnsGrid.js", "bg": true}}

## 设计局限

### 负边距

The spacing between items is implemented with a negative margin. This might lead to unexpected behaviors. For instance, to apply a background color, you need to apply `display: flex;` to the parent.

### white-space: nowrap;

The initial setting on flex items is `min-width: auto`. It's causing a positioning conflict when the children is using `white-space: nowrap;`. You can experience the issue with:

```jsx
<Grid item xs>
  <Typography noWrap>
```

In order for the item to stay within the container you need to set `min-width: 0`. In practice, you can set the `zeroMinWidth` prop:

```jsx
<Grid item xs zeroMinWidth>
  <Typography noWrap>
```

{{"demo": "AutoGridNoWrap.js", "bg": true}}

### direction: column | column-reverse

The `xs`, `sm`, `md`, `lg`, and `xl` props are **not supported** within `direction="column"` and `direction="column-reverse"` containers.

They define the number of grids the component will use for a given breakpoint. They are intended to control **width** using `flex-basis` in `row` containers but they will impact height in `column` containers. If used, these props may have undesirable effects on the height of the `Grid` item elements.

## CSS 栅格布局

The `Grid` component is using CSS flexbox internally. But as seen below, you can easily use [the system](/system/grid/) and CSS Grid to layout your pages.

{{"demo": "CSSGrid.js", "bg": true}}

## 系统属性

As a CSS utility component, the `Grid` supports all [`system`](/system/properties/) properties. You can use them as props directly on the component. For instance, a padding:

```jsx
<Grid item p={2}>
```
