# Designer

<p class="description">Design is critical to our success. We're looking for skills that complement those of our Lead Designer. You'll help to design the tools that enable our audience to build outstanding-looking UIs.</p>

## About the company

MUI started with Material UI, the most successful React implementation of Google's Material Design.
It has gained a large following, not only due to the fidelity to Material Design, but also because of the number of components, its carefully designed component API, obsession for details, and community engagement.
Today, countless teams and organizations rely on our open-source libraries to build their design system.

A couple of years ago, we started to expand our suite of products.
We released [MUI X](/x/), a collection of advanced components; [MUI Design kits](/design-kits/), the MUI components available for the most popular design tools; and also host [Templates](/templates/), a set of pre-built UI kits.
We've seen rapid growth with all of them (2-3x per year) and we have more to come.

We are a fully distributed team, spread across multiple timezones.
We work mainly asynchronously, relying mostly on written collaboration.
Every contributor has the freedom to define how they work — the rest of us won't know what you're doing day-to-day unless you tell us.
For additional details about the MUI team and culture, you can check our [careers](/careers/) and [about](/about/) pages and also our [public Handbook](https://mui-org.notion.site/Handbook-f086d47e10794d5e839aef9dc67f324b).

## Why we're hiring

Material UI started as an open-source project.
Over time, the audience and usage grew considerably, and some of the library's early contributors became full-time maintainers.
A company was incorporated to support this growth, and more recently [was rebranded from Material UI to MUI](/blog/material-ui-is-now-mui/).
The new brand was fundamental to set the stage for MUI to become larger than Material Design, which was something we were already doing.
Currently, we have five main projects that are not at all related to MD:

- [MUI Core](/core/):
  - [MUI Base](/base/getting-started/overview/): the unstyled version of the components.
  - [MUI System](/system/getting-started/overview/): our most recent take on styling for React components.
  - [MUI Joy (working title)](https://github.com/mui/material-ui/discussions/29024): a second design system as an alternative to Material Design.
- [MUI X](/x/): as mentioned, a growing set of advanced components.
  Today, the flagship is the [Data Grid](/x/react-data-grid/), a game-changing component for presenting large amounts of data, which integrates perfectly with MUI Core.
- MUI Toolpad: a very recent endeavor aimed at exploring how our users can visually create apps 10x faster with the power of low-code and the flexibility of pro-code.

We also know, especially due to [our annual developer survey](/blog/2021-developer-survey-results/), that design quality plays a huge part when developers are considering component library options.
Therefore, we need to grow the design team to help us push these initiatives further.

## About the role

Some criteria for applying to this role:

- Location: fully remote (preference for UTC-6 to UTC +3).
- Type of work: full-time (as a contractor or employee, [depending primarily on location](https://mui-org.notion.site/Hiring-FAQ-64763b756ae44c37b47b081f98915501)).
- Level: [3 or above](https://docs.google.com/spreadsheets/d/18VvbVCNBRWu-QYPncBl5IWTXTOpD68UQsLsymBvfm88/edit#gid=0).

We need someone experienced enough to help two different teams with hard problems.
You'll be responsible for ensuring that the MUI Toolpad and MUI X teams have spot-on design and product work.
Given that each product is at a different stage, at this moment we believe that one person is enough to oversee the design function for both teams.
You'll have the freedom, trust, and help you need to balance and tackle all the work.
You'll also be the second designer of a growing design team, so we'll also need your help to shape this growth.

### Here are a few initiatives you might work on

- Help design the first version of MUI Toolpad, from early strategy to its look and feel.
- Evolve and refine the Data Grid UX for features such as filtering, column pinning, row editing, and more.
- Help set the bar higher for MUI X documentation, from visual design to copywriting.
- Support the design team growth by promoting design/product culture, and hiring new members.

### You might fit for this role if you

- See yourself as a generalist designer, tackling problems ranging from strategic thinking to execution. (More insight in the [first draft of our design philosophy](https://mui-org.notion.site/Design-philosophy-bdbef60d6fad4134a43870df3e452ebc), available in our public Handbook).
- Have excellent visual and interaction design skills.
- Consider yourself a great communicator, both written and verbal.
  Designers are key players when it comes to creating alignment and shared understanding, whether with internal or external stakeholders.
- Feel comfortable around code and git (we use GitHub).
  Developers are MUI's main audience, so it's very important to experience our technology for yourself, to empathize with our users.
  You should be capable of tweaking JSX and CSS, ensuring that your designs are implemented with the highest fidelity.
  But don't worry, you'll always have the support of your teams' developers.

Previous experience with design systems would be great but is not required.

## Benefits & Compensation

We offer competitive compensation, aligned with your profile and location.
We're ready to pay top market rates for a designer that can significantly push the mission forward.
Other perks are described on [the careers page](/careers/#perks-amp-benefits/).

## How to apply?

[Apply now for this position 📮](https://jobs.ashbyhq.com/MUI/__ID__/application?utm_source=ZNRrPGBkqO).

## What happens next?

We start by screening applications, looking for designers that showcase the desired skills and experience.
If your application stands out, we'll contact you for a get-to-know conversation, where we'll meet each other.

If that goes well, you'll be invited to up to four additional conversations, those being:

- A walkthrough of one or two selected projects that you believe demonstrate [comparable experience.](https://articles.uie.com/ux-hiring-lets-talk-about-comparable-experience/)
- A chat with one of the product managers or engineers that you will work closely with.
- A chat with one of MUI's founders.
- A possible follow-up chat if we missed addressing anything relevant in the previous conversations.

All these conversations will be 1:1 and over video chat.
Please ask as many questions as you wish throughout the whole process, it's a two-way discussion.
If you happen to need additional conversations as well, feel free to ask; we'll be happy to schedule them.
Lastly, please note that we're unable to offer individual feedback during the initial screening process, as we're a small team and don't have the bandwidth to do so.

We look forward to hearing from you! ☺️
