# Developer Advocate

<p class="description">You will educate users on the latest features, craft high-quality examples, and demos, engage with the community, write documentation, advocate for creating faster and more appealing UIs, and help to promote the advanced components.</p>

## Details of the Role

- Location: Remote (preference for UTC-7 to UTC+2).
- Type of work: Full-time (contractor or employee [depending on circumstances](https://mui-org.notion.site/Hiring-FAQ-64763b756ae44c37b47b081f98915501))
- We're a remote company, we prefer asynchronous communication over meetings.
- We work independently, the rest of us won't know what you're doing day-to-day unless you tell us.

## About the company

MUI started with Material UI, the most successful React implementation of Google's Material Design.
It has gained a large following, not only due to the fidelity to Material Design, but also because of the number of components, its carefully designed component API, obsession for details, and community engagement.
Today, countless teams and organizations rely on our open-source libraries to build their design system.

A couple of years ago, we started to expand our suite of products.
We released [MUI X](/x/), a collection of advanced components; [MUI Design kits](/design-kits/), the MUI components available for the most popular design tools; and also host [Templates](/templates/), a set of pre-built UI kits.
We've seen rapid growth with all of them (2-3x per year) and we have more to come.

We are a fully distributed team, spread across multiple timezones.
We work mainly asynchronously, relying mostly on written collaboration.
Every contributor has the freedom to define how they work — the rest of us won't know what you're doing day-to-day unless you tell us.
For additional details about the MUI team and culture, you can check our [careers](/careers/) and [about](/about/) pages and also our [public Handbook](https://mui-org.notion.site/Handbook-f086d47e10794d5e839aef9dc67f324b).

## Why we're hiring

Both our open-source community and our premium products are growing fast (x2-3 YoY).
We need talented people to keep that going!

We are looking for a dedicated educator and experienced developer to join us as a Developer Advocate to help people get familiar with and use MUI most effectively.

In our [last developer survey](/blog/2021-developer-survey-results/#5-how-can-we-improve-mui-for-you), we learned that have a long way to go in helping developers to be successful with our technology.
We have underinvested in this area for too long.
Your mission will be to be the voice of the developers of the community inside the company.
We are looking for someone that can contribute to the following outcomes:

- Amplify the need of the community so the product direction aims at what people need the most.
- Improve the overall developer experience, resulting in better NPS & CSAT scores, e.g. though educational content.
- Create momentum in the React community and drive adoption of the library.

## About the role

### Why this is interesting

You will be the first person focusing full-time on developer relations at MUI.
You will lay the foundations for a team that could grow over time.

Our solution empowers React developers to build awesome applications faster – we see over a million developers on MUI's docs every month.
Hundreds of thousands of developers use MUI every month.

### What you'll do on a day-to-day basis

Depending on the day, you'll:

- You will monitor success metrics, consider how effective initiatives are at achieving goals, and adjust effort accordingly.
- You will create and implement plans to build, enable and nurture the community.
- You will compose interesting blog posts. You will be writing tutorials and other technical content.
- You will participate in and speak at events, and online live streams.
- You will build inspiring apps, examples, and improve the documentation where needed.
- You will create technical videos, video tutorials, demos, and additional videos for [our YouTube channel](https://www.youtube.com/channel/UCUdh2wVTrd7hErLo9Rh0HsQ).
- You will give feedback to product management, to influence the product roadmaps based on developers' needs.
- You will make sure contributions to the documentation are of high quality, sharing best practices with the developers.
- You will help other team members grow at engaging with the community. For instance by encouraging and providing critical feedback on new blog posts.
- You will rework the pages of the documentation that are confusing, base on feedback.
- You will follow GitHub issues to understand where developers face frustration and develop strategies to overcome these. This could be suggesting or implementing documentation updates, or proposing or contributing code changes that solve the core issue.

For the right candidate:

- Working with the Leadership to construct and execute on a hiring plan to grow the Developer Experience team.

### Here are a few initiatives you might work on

- Create a learning section in the documentation for hybrid written and video tutorials.
- Own the Algolia search experience, improving the content on the most frequent search queries.
- Take ownership of the company's Twitter account.
- Level up the showcase, cherry-picking the best websites and apps of the community.
- Revamp the blog post infrastructure to empower the rest of the team to create more content.
- Start a monthly newsletter to engage with the community.
- Organize a MUI Conf
- Think about creative ways to promote MUI X, MUI X Pro, and new products.

## About you

### Skills you should have

- You are fluent in English (both written and spoken). You'll be the face of MUI in the world, and make everyone in the company proud of the Developer Experience team.
- You are a highly empathic person.
- You are passionate about helping other developers solve problems and have an educational mindset.
- You have some formal or informal experience in teaching: training, tutoring, mentoring, etc.
- Hands-on developer who is comfortable with full-stack development.
- You are passionate about UI development.

### What would be nice if you had, but isn't required

- Experience in building community across some of the following channels: Twitter, YouTube, Twitch, Discord, blogs, meetups, public speaking & events
- Experience working with open-source and/or with the open-source community.
- Experience working with/editing video.
- Experience using MUI.

## Benefits & Compensation

Competitive compensation depending on the profile and location.
We are ready to pay top market rates for a person that can clearly exceed the role's expectations.
You can find the other perks & benefits on the [careers](/careers/#perks-amp-benefits) page.

## How to apply?

[Apply now for this position 📮](https://jobs.ashbyhq.com/MUI/__ID__/application?utm_source=ZNRrPGBkqO)
