# React Support Engineer - X

<p class="description">You will provide support, remove blockers and unwrap potential features from reported issues for the advanced components team. You will directly impact developers' satisfaction and success.</p>

## Details of the Role

- Location: Remote (preference for UTC-6 to UTC+5).
- Type of work: Full-time (contractor or employee [depending on circumstances](https://mui-org.notion.site/Hiring-FAQ-64763b756ae44c37b47b081f98915501))
- Level: [4 or above](https://docs.google.com/spreadsheets/d/1dDdPD-flNXlgZ0E3ZxVvCDx27RFuhVWJrcfcjNu_I8k/edit#gid=0).
- We're a remote company, we prefer asynchronous communication over meetings.
- We work independently, the rest of us won't know what you're doing day-to-day unless you tell us.

## About the company

MUI started with Material UI, the most successful React implementation of Google's Material Design.
It has gained a large following, not only due to the fidelity to Material Design, but also because of the number of components, its carefully designed component API, obsession for details, and community engagement.
Today, countless teams and organizations rely on our open-source libraries to build their design system.

A couple of years ago, we started to expand our suite of products.
We released [MUI X](/x/), a collection of advanced components; [MUI Design kits](/design-kits/), the MUI components available for the most popular design tools; and also host [Templates](/templates/), a set of pre-built UI kits.
We've seen rapid growth with all of them (2-3x per year) and we have more to come.

We are a fully distributed team, spread across multiple timezones.
We work mainly asynchronously, relying mostly on written collaboration.
Every contributor has the freedom to define how they work — the rest of us won't know what you're doing day-to-day unless you tell us.
For additional details about the MUI team and culture, you can check our [careers](/careers/) and [about](/about/) pages and also our [public Handbook](https://mui-org.notion.site/Handbook-f086d47e10794d5e839aef9dc67f324b).

## Why we're hiring

Both our open-source community and our premium products are growing fast (x2-3 YoY).
We need talented people to keep that going!

We need a Support Engineer to solve friction points of users.
We face challenges on multiple fronts:

- As a result of this growth, we (will) have more users questions and feedback coming in than ever before.
- The commercial version of the library is growing, but our community of developers is still small and has a reduced incentive to contribute compared to the community plan.
- Software engineers at MUI are tasked with doing support, however, they could benefit from the help of a dedicated person in the company, for instance to improve the workflows and tooling.
- The MUI X Premium plan will offer a technical advisor service, we need a Support Engineer to help deliver it.

## About the role

### Why this is interesting

You will be a key member of the Developer Experience's team and will directly impact customer satisfaction and success.
You will troubleshoot complex issues related to MUI.
At MUI a Support Engineer is as considered as a Developer, it's a person that enjoys optimizing what already exists more than working on new shiny features.

Our solution empowers React developers to build awesome applications faster – we see over a million developers on MUI's docs every month.
Hundreds of thousands of developers use MUI every month.

### What you'll do on a day-to-day basis

You will own the following responsibilities:

- **Build product knowledge**. You will continually research and learn the current and future best practices of using MUI.
- **Resolve users' issues**. You will solve these issues at two levels:
  - On the surface, you will answer developers on GitHub, Zendesk, Twitter, email, Slack.
  - At the root, you will create/update the documentation, fix bugs in collaboration with the relevant developer, and more.
- **Provide feedback**. You will work alongside product managers to define and shape the product goals, roadmap, priorities, and strategy based on your frontline knowledge of customer needs.
- **Operations**.
  - You will establish key support metrics and identify how best to measure them.
  - You will establish workflow to reduce 'time to response' and 'time to fix' that can scale to multiple team members.
  - You will identify where internal tooling might be developed or obtained to improve support efficiency.

For the right candidate:

- Working with the Leadership to construct and execute a hiring plan to grow the support team.

Depending on the day, you'll:

- **You'll be interacting with the users** on a regular basis, handling inbound support and feature requests (every developer helps with developer requests).
- **Reduce friction**.
  A large amount of the work on MUI is reducing friction and making it easier to use.
  This might involve careful API design, identifying and fixing top bugs, creating easier to understand error messages, and writing documentation and blog posts about features you ship.
- **Collaborate with the community**.
  Many small as well as meaningful fixes and features have been contributed by the community. Your role is to draw the best out of the community — to inspire those across the world to create and contribute through your reviews of their issues and pull requests.
- **Experiment and play**. Great, unexpected features and heisenbug fixes have come from a number of sources — relentlessly methodical processes of elimination, free-flowing team collaboration, inspiration by adjacent libraries and projects, and difficult-to-explain individual strokes of brilliance. Whatever your preferred style is for creating new things that others might not have thought of, you'll find a welcome home on the team.
- **Ship. Early and often**. You'll iterate and ship frequently.
  You'll have a real impact on the end-user experience and you'll love working on a team that builds stunning UIs and prioritizes delivering real user value as often as possible.

## About you

We're looking for someone with strong front-end skills. More important than specific technical skills though is that you're a strong problem solver who loves to learn. Details matter to you.

### Skills you should have

- **Expertise in the modern JavaScript ecosystem**.
  MUI is built on the shoulders of giants, making use of technologies such as ES2021, TypeScript, Node.js, React, Next.js, webpack, and Babel.
- **A track record of demonstrating an eye for product and solving real-world user problems**. If you have a knack for solving problems at the root cause, shipping beautiful user interfaces and intuitive APIs, we want you on our team.
- **Strong written and verbal communication skills**.
  As part of the team, you'll interface both directly and indirectly with community members and enterprise customers, and contribute to user documentation. Clear communication is fundamental in creating intuitive and compelling resources.
- **Ability to dive into complex problems**.
  You should be able to quickly assess, understand, and iterate upon aspects of our codebase.
- **Ready and willing to ask and answer questions**.
  If you're comfortable saying you're unsure, asking for help; but equally reaching out to assist others, you'll be an incredible addition to our team. We thrive because of continuous learning. First-time mistakes should be celebrated, not blamed.
- **Avoid monolithic deliverables**.
  You scope and stage your work into well-defined milestones to ship.
- **Past work with front-end infrastructure**.
  Perhaps you've created your company's design system, written a Babel plugin, or written complex React components.
  It would be great if you could address this in your cover letter!

### What it would be nice if you had, but isn't required

- **You've contributed to a design system before**.
  You have worked on enterprise components in the past, maybe for internal use in your company.
  You have built complex and advanced features while making sure the accessibility was fully functional.
- **You've maintained an active repository before**.
  Maybe you've helped maintain a popular open-source repository, or perhaps you've worked on internal repositories that saw contributions from multiple teams.
  Previous experience with highly active repository workflows is a definite plus for this role.
- **You have contributed code to MUI before**. A history of contributing to MUI would be a definite plus.

## Benefits & Compensation

Competitive compensation depending on the profile and location.
We are ready to pay top market rates for a person that can clearly exceed the role's expectations.
You can find the other perks & benefits on the [careers](/careers/#perks-amp-benefits) page.

## How to apply?

[Apply now for this position 📮](https://jobs.ashbyhq.com/MUI/e362a14c-6674-4ac9-8eee-bcf44a8767c8/application?utm_source=ZNRrPGBkqO)
