import React from 'react';
import { OptionUnstyledProps } from '../OptionUnstyled';
import { OptionGroupUnstyledProps } from '../OptionGroupUnstyled';
import { isOptionGroup, SelectChild, SelectOption, SelectOptionGroup } from './useSelect.types';

export function areOptionsEqual<TValue>(
  option1: SelectOption<TValue>,
  option2: SelectOption<TValue>,
) {
  return (
    option1.label === option2.label &&
    option1.value === option2.value &&
    option1.disabled === option2.disabled
  );
}

export function getOptionsFromChildren<TValue>(children: React.ReactNode): SelectChild<TValue>[] {
  if (children == null) {
    return [];
  }

  const selectChildren: SelectChild<TValue>[] = [];

  React.Children.forEach(children, (node: React.ReactNode) => {
    const nodeChildren = (node as React.ReactElement)?.props?.children;
    if ((node as React.ReactElement)?.props?.value === undefined) {
      if (nodeChildren != null) {
        const element = node as React.ReactElement<OptionGroupUnstyledProps>;

        const group: SelectOptionGroup<TValue> = {
          options: getOptionsFromChildren<TValue>(nodeChildren),
          label: element.props.label,
          disabled: element.props.disabled ?? false,
        };

        selectChildren.push(group);
      }

      return;
    }

    const element = node as React.ReactElement<OptionUnstyledProps<TValue>>;

    const option = {
      value: element.props.value,
      label: element.props.label || element.props.children,
      disabled: element.props.disabled ?? false,
    };

    selectChildren.push(option);
  });

  return selectChildren ?? [];
}

export function flattenOptionGroups<TValue>(
  groupedOptions: SelectChild<TValue>[],
  isGroupDisabled: boolean = false,
): SelectOption<TValue>[] {
  let flatOptions: SelectOption<TValue>[] = [];
  groupedOptions.forEach((optionOrGroup) => {
    if (isOptionGroup(optionOrGroup)) {
      flatOptions = flatOptions.concat(
        flattenOptionGroups(optionOrGroup.options, optionOrGroup.disabled),
      );
    } else {
      flatOptions.push({
        ...optionOrGroup,
        disabled: isGroupDisabled || optionOrGroup.disabled,
      });
    }
  });

  return flatOptions;
}
