import * as React from 'react';
import { OverridableStringUnion, OverrideProps } from '@mui/types';
import { ColorPaletteProp, SxProps, VariantProp } from '../styles/types';

export type TabSlot = 'root';

export interface TabPropsColorOverrides {}

export interface TabPropsVariantOverrides {}

export interface TabTypeMap<P = {}, D extends React.ElementType = 'button'> {
  props: P & {
    /**
     * A ref for imperative actions. It currently only supports `focusVisible()` action.
     */
    action?: React.Ref<{
      focusVisible(): void;
    }>;
    /**
     * The color of the component. It supports those theme colors that make sense for this component.
     * @default 'neutral'
     */
    color?: OverridableStringUnion<ColorPaletteProp, TabPropsColorOverrides>;
    /**
     * If `true`, the component is disabled.
     * @default false
     */
    disabled?: boolean;
    /**
     * The content direction flow.
     * @default 'horizontal'
     */
    orientation?: 'horizontal' | 'vertical';
    /**
     * The system prop that allows defining system overrides as well as additional CSS styles.
     */
    sx?: SxProps;
    /**
     * You can provide your own value. Otherwise, we fall back to the child position index.
     */
    value?: number | string;
    /**
     * Callback invoked when new value is being set.
     */
    onChange?: (event: React.SyntheticEvent, value: number | string) => void;
    /**
     * The variant to use.
     * @default 'plain'
     */
    variant?: OverridableStringUnion<VariantProp, TabPropsVariantOverrides>;
  };
  defaultComponent: D;
}

export type TabProps<
  D extends React.ElementType = TabTypeMap['defaultComponent'],
  P = { component?: React.ElementType },
> = OverrideProps<TabTypeMap<P, D>, D>;

export interface TabOwnerState extends TabProps {
  /**
   * If `true`, the tab is activated by mouse or keyboard.
   */
  active: boolean;
  /**
   * If `true`, the tab's focus is visible.
   */
  focusVisible: boolean;
  /**
   * If `true`, the tab is disabled.
   */
  disabled: boolean;
  /**
   * If `true`, the tab is disabled.
   */
  selected: boolean;
  /**
   * @internal
   */
  row: boolean;
}
